@@ -1318,7 +1318,9 @@ def readATLASddetHeader(filename, delimiter = '= ', useOrderedDict = False):
 #                where we have flattened data with no foreign keys. Inefficient (uses too much
 #                memory by inflating the size of each row), but effective.
 # 2022-10-10 KWS Added a rownum column. If set, each row will have an extra column name with the
-#                index offset. (Allows database inserts to be compared with source files.)
+#                index offset. (Allows database inserts to be compared with source files.) Note
+#                that the rownum column has been cast as a string for compatibility reasons.
+# 2022-11-07 KWS New skipLines = -1 option == guess where the table header lives.
 def readGenericDataFile(filename, delimiter = ' ', skipLines = 0, fieldnames = None, useOrderedDict = False, appendheaderlines=False, headerdelimiter='=', headerprefix='#', headerkeycollisionsuffix='HEAD', rownumcolumn=None):
    """readGenericDataFile.
 
@@ -1344,6 +1346,22 @@ def readGenericDataFile(filename, delimiter = ' ', skipLines = 0, fieldnames = N
    else:
       f = open(filename)
 
+   data = []
+
+   lineNumber = 0
+   if skipLines == -1:
+      # Iterate through the file and figure out where the table header is. It's the
+      # commented line just before the data where there is no hash symbol.
+      try:
+         while f.readline()[0] == '#':
+            lineNumber += 1
+      except IndexError as e:
+         # We got to the end of the file and there is no actual data.
+         return data
+      # Go back to the beginning of the file.
+      f.seek(0,0)
+      skipLines = lineNumber - 1
+
    headerdata = {}
    if skipLines > 0:
       if appendheaderlines:
@@ -1376,11 +1394,10 @@ def readGenericDataFile(filename, delimiter = ' ', skipLines = 0, fieldnames = N
 
    t = csv.DictReader(f, fieldnames = fieldnames, delimiter=delimiter, skipinitialspace = True)
 
-   data = []
    counter = 0
    for row in t:
       if rownumcolumn:
-          row[rownumcolumn] = counter
+          row[rownumcolumn] = str(counter)
           fieldnames.append(rownumcolumn)
       if useOrderedDict:
           od = OrderedDict((key, row[key]) for key in fieldnames)
